==> vtk-8.1.1-3-armv6h.pkg.tar.xz: vtk/vtkAxis.java <==
// java wrapper for vtkAxis object
//

package vtk;
import vtk.*;

public class vtkAxis extends vtkContextItem
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetPosition_2(int id0);
  public void SetPosition(int id0)
    { SetPosition_2(id0); }

  private native int GetPosition_3();
  public int GetPosition()
    { return GetPosition_3(); }

  private native void SetPoint1_4(double id0,double id1);
  public void SetPoint1(double id0,double id1)
    { SetPoint1_4(id0,id1); }

  private native double[] GetPoint1_5();
  public double[] GetPoint1()
    { return GetPoint1_5(); }

  private native void SetPoint2_6(double id0,double id1);
  public void SetPoint2(double id0,double id1)
    { SetPoint2_6(id0,id1); }

  private native double[] GetPoint2_7();
  public double[] GetPoint2()
    { return GetPoint2_7(); }

  private native void SetNumberOfTicks_8(int id0);
  public void SetNumberOfTicks(int id0)
    { SetNumberOfTicks_8(id0); }

  private native int GetNumberOfTicks_9();
  public int GetNumberOfTicks()
    { return GetNumberOfTicks_9(); }

  private native void SetTickLength_10(double id0);
  public void SetTickLength(double id0)
    { SetTickLength_10(id0); }

  private native double GetTickLength_11();
  public double GetTickLength()
    { return GetTickLength_11(); }

  private native long GetLabelProperties_12();
  public vtkTextProperty GetLabelProperties() {
    long temp = GetLabelProperties_12();

    if (temp == 0) return null;
    return (vtkTextProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetMinimum_13(double id0);
  public void SetMinimum(double id0)
    { SetMinimum_13(id0); }

  private native double GetMinimum_14();
  public double GetMinimum()
    { return GetMinimum_14(); }

  private native void SetMaximum_15(double id0);
  public void SetMaximum(double id0)
    { SetMaximum_15(id0); }

  private native double GetMaximum_16();
  public double GetMaximum()
    { return GetMaximum_16(); }

  private native void SetUnscaledMinimum_17(double id0);
  public void SetUnscaledMinimum(double id0)
    { SetUnscaledMinimum_17(id0); }

  private native double GetUnscaledMinimum_18();
  public double GetUnscaledMinimum()
    { return GetUnscaledMinimum_18(); }

  private native void SetUnscaledMaximum_19(double id0);
  public void SetUnscaledMaximum(double id0)
    { SetUnscaledMaximum_19(id0); }

  private native double GetUnscaledMaximum_20();
  public double GetUnscaledMaximum()
    { return GetUnscaledMaximum_20(); }

  private native void SetRange_21(double id0,double id1);
  public void SetRange(double id0,double id1)
    { SetRange_21(id0,id1); }

  private native void SetRange_22(double id0[]);
  public void SetRange(double id0[])
    { SetRange_22(id0); }

  private native void SetUnscaledRange_23(double id0,double id1);
  public void SetUnscaledRange(double id0,double id1)
    { SetUnscaledRange_23(id0,id1); }

  private native void SetUnscaledRange_24(double id0[]);
  public void SetUnscaledRange(double id0[])
    { SetUnscaledRange_24(id0); }

  private native void SetMinimumLimit_25(double id0);
  public void SetMinimumLimit(double id0)
    { SetMinimumLimit_25(id0); }

  private native double GetMinimumLimit_26();
  public double GetMinimumLimit()
    { return GetMinimumLimit_26(); }

  private native void SetMaximumLimit_27(double id0);
  public void SetMaximumLimit(double id0)
    { SetMaximumLimit_27(id0); }

  private native double GetMaximumLimit_28();
  public double GetMaximumLimit()
    { return GetMaximumLimit_28(); }

  private native void SetUnscaledMinimumLimit_29(double id0);
  public void SetUnscaledMinimumLimit(double id0)
    { SetUnscaledMinimumLimit_29(id0); }

  private native double GetUnscaledMinimumLimit_30();
  public double GetUnscaledMinimumLimit()
    { return GetUnscaledMinimumLimit_30(); }

  private native void SetUnscaledMaximumLimit_31(double id0);
  public void SetUnscaledMaximumLimit(double id0)
    { SetUnscaledMaximumLimit_31(id0); }

  private native double GetUnscaledMaximumLimit_32();
  public double GetUnscaledMaximumLimit()
    { return GetUnscaledMaximumLimit_32(); }

  private native int[]  GetMargins_33();
  public int[]  GetMargins()
    { return GetMargins_33(); }

  private native void SetMargins_34(int id0,int id1);
  public void SetMargins(int id0,int id1)
    { SetMargins_34(id0,id1); }

  private native void SetMargins_35(int id0[]);
  public void SetMargins(int id0[])
    { SetMargins_35(id0); }

  private native void SetTitle_36(String id0);
  public void SetTitle(String id0)
    { SetTitle_36(id0); }

  private native String GetTitle_37();
  public String GetTitle()
    { return GetTitle_37(); }

  private native long GetTitleProperties_38();
  public vtkTextProperty GetTitleProperties() {
    long temp = GetTitleProperties_38();

    if (temp == 0) return null;
    return (vtkTextProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native boolean GetLogScaleActive_39();
  public boolean GetLogScaleActive()
    { return GetLogScaleActive_39(); }

  private native boolean GetLogScale_40();
  public boolean GetLogScale()
    { return GetLogScale_40(); }

  private native void SetLogScale_41(boolean id0);
  public void SetLogScale(boolean id0)
    { SetLogScale_41(id0); }

  private native void LogScaleOn_42();
  public void LogScaleOn()
    { LogScaleOn_42(); }

  private native void LogScaleOff_43();
  public void LogScaleOff()
    { LogScaleOff_43(); }

  private native void SetGridVisible_44(boolean id0);
  public void SetGridVisible(boolean id0)
    { SetGridVisible_44(id0); }

  private native boolean GetGridVisible_45();
  public boolean GetGridVisible()
    { return GetGridVisible_45(); }

  private native void SetLabelsVisible_46(boolean id0);
  public void SetLabelsVisible(boolean id0)
    { SetLabelsVisible_46(id0); }

  private native boolean GetLabelsVisible_47();
  public boolean GetLabelsVisible()
    { return GetLabelsVisible_47(); }

  private native void SetRangeLabelsVisible_48(boolean id0);
  public void SetRangeLabelsVisible(boolean id0)
    { SetRangeLabelsVisible_48(id0); }

  private native boolean GetRangeLabelsVisible_49();
  public boolean GetRangeLabelsVisible()
    { return GetRangeLabelsVisible_49(); }

  private native void SetLabelOffset_50(double id0);
  public void SetLabelOffset(double id0)
    { SetLabelOffset_50(id0); }

  private native double GetLabelOffset_51();
  public double GetLabelOffset()
    { return GetLabelOffset_51(); }

  private native void SetTicksVisible_52(boolean id0);
  public void SetTicksVisible(boolean id0)
    { SetTicksVisible_52(id0); }

  private native boolean GetTicksVisible_53();
  public boolean GetTicksVisible()
    { return GetTicksVisible_53(); }

  private native void SetAxisVisible_54(boolean id0);
  public void SetAxisVisible(boolean id0)
    { SetAxisVisible_54(id0); }

  private native boolean GetAxisVisible_55();
  public boolean GetAxisVisible()
    { return GetAxisVisible_55(); }

  private native void SetPrecision_56(int id0);
  public void SetPrecision(int id0)
    { SetPrecision_56(id0); }

  private native int GetPrecision_57();
  public int GetPrecision()
    { return GetPrecision_57(); }

  private native void SetLabelFormat_58(String id0);
  public void SetLabelFormat(String id0)
    { SetLabelFormat_58(id0); }

  private native String GetLabelFormat_59();
  public String GetLabelFormat()
    { return GetLabelFormat_59(); }

  private native void SetRangeLabelFormat_60(String id0);
  public void SetRangeLabelFormat(String id0)
    { SetRangeLabelFormat_60(id0); }

  private native String GetRangeLabelFormat_61();
  public String GetRangeLabelFormat()
    { return GetRangeLabelFormat_61(); }

  private native void SetNotation_62(int id0);
  public void SetNotation(int id0)
    { SetNotation_62(id0); }

  private native int GetNotation_63();
  public int GetNotation()
    { return GetNotation_63(); }

  private native void SetBehavior_64(int id0);
  public void SetBehavior(int id0)
    { SetBehavior_64(id0); }

  private native int GetBehavior_65();
  public int GetBehavior()
    { return GetBehavior_65(); }

  private native long GetPen_66();
  public vtkPen GetPen() {
    long temp = GetPen_66();

    if (temp == 0) return null;
    return (vtkPen)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetGridPen_67();
  public vtkPen GetGridPen() {
    long temp = GetGridPen_67();

    if (temp == 0) return null;
    return (vtkPen)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetTickLabelAlgorithm_68(int id0);
  public void SetTickLabelAlgorithm(int id0)
    { SetTickLabelAlgorithm_68(id0); }

  private native int GetTickLabelAlgorithm_69();
  public int GetTickLabelAlgorithm()
    { return GetTickLabelAlgorithm_69(); }

  private native void SetScalingFactor_70(double id0);
  public void SetScalingFactor(double id0)
    { SetScalingFactor_70(id0); }

  private native double GetScalingFactor_71();
  public double GetScalingFactor()
    { return GetScalingFactor_71(); }

  private native void SetShift_72(double id0);
  public void SetShift(double id0)
    { SetShift_72(id0); }

  private native double GetShift_73();
  public double GetShift()
    { return GetShift_73(); }

  private native void Update_74();
  public void Update()
    { Update_74(); }

  private native boolean Paint_75(vtkContext2D id0);
  public boolean Paint(vtkContext2D id0)
    { return Paint_75(id0); }

  private native void AutoScale_76();
  public void AutoScale()
    { AutoScale_76(); }

  private native void RecalculateTickSpacing_77();
  public void RecalculateTickSpacing()
    { RecalculateTickSpacing_77(); }

  private native long GetTickPositions_78();
  public vtkDoubleArray GetTickPositions() {
    long temp = GetTickPositions_78();

    if (temp == 0) return null;
    return (vtkDoubleArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetTickScenePositions_79();
  public vtkFloatArray GetTickScenePositions() {
    long temp = GetTickScenePositions_79();

    if (temp == 0) return null;
    return (vtkFloatArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetTickLabels_80();
  public vtkStringArray GetTickLabels() {
    long temp = GetTickLabels_80();

    if (temp == 0) return null;
    return (vtkStringArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native boolean SetCustomTickPositions_81(vtkDoubleArray id0,vtkStringArray id1);
  public boolean SetCustomTickPositions(vtkDoubleArray id0,vtkStringArray id1)
    { return SetCustomTickPositions_81(id0,id1); }

  private native double NiceNumber_82(double id0,boolean id1);
  public double NiceNumber(double id0,boolean id1)
    { return NiceNumber_82(id0,id1); }

  private native String GenerateSimpleLabel_83(double id0);
  public String GenerateSimpleLabel(double id0)
    { return GenerateSimpleLabel_83(id0); }

  public vtkAxis() { super(); }

  public vtkAxis(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-7-armv6h.pkg.tar.xz: vtk/vtkAxis.java <==
// java wrapper for vtkAxis object
//

package vtk;
import vtk.*;

public class vtkAxis extends vtkContextItem
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetPosition_2(int id0);
  public void SetPosition(int id0)
    { SetPosition_2(id0); }

  private native int GetPosition_3();
  public int GetPosition()
    { return GetPosition_3(); }

  private native void SetPoint1_4(double id0,double id1);
  public void SetPoint1(double id0,double id1)
    { SetPoint1_4(id0,id1); }

  private native double[] GetPoint1_5();
  public double[] GetPoint1()
    { return GetPoint1_5(); }

  private native void SetPoint2_6(double id0,double id1);
  public void SetPoint2(double id0,double id1)
    { SetPoint2_6(id0,id1); }

  private native double[] GetPoint2_7();
  public double[] GetPoint2()
    { return GetPoint2_7(); }

  private native void SetNumberOfTicks_8(int id0);
  public void SetNumberOfTicks(int id0)
    { SetNumberOfTicks_8(id0); }

  private native int GetNumberOfTicks_9();
  public int GetNumberOfTicks()
    { return GetNumberOfTicks_9(); }

  private native void SetTickLength_10(double id0);
  public void SetTickLength(double id0)
    { SetTickLength_10(id0); }

  private native double GetTickLength_11();
  public double GetTickLength()
    { return GetTickLength_11(); }

  private native long GetLabelProperties_12();
  public vtkTextProperty GetLabelProperties() {
    long temp = GetLabelProperties_12();

    if (temp == 0) return null;
    return (vtkTextProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetMinimum_13(double id0);
  public void SetMinimum(double id0)
    { SetMinimum_13(id0); }

  private native double GetMinimum_14();
  public double GetMinimum()
    { return GetMinimum_14(); }

  private native void SetMaximum_15(double id0);
  public void SetMaximum(double id0)
    { SetMaximum_15(id0); }

  private native double GetMaximum_16();
  public double GetMaximum()
    { return GetMaximum_16(); }

  private native void SetUnscaledMinimum_17(double id0);
  public void SetUnscaledMinimum(double id0)
    { SetUnscaledMinimum_17(id0); }

  private native double GetUnscaledMinimum_18();
  public double GetUnscaledMinimum()
    { return GetUnscaledMinimum_18(); }

  private native void SetUnscaledMaximum_19(double id0);
  public void SetUnscaledMaximum(double id0)
    { SetUnscaledMaximum_19(id0); }

  private native double GetUnscaledMaximum_20();
  public double GetUnscaledMaximum()
    { return GetUnscaledMaximum_20(); }

  private native void SetRange_21(double id0,double id1);
  public void SetRange(double id0,double id1)
    { SetRange_21(id0,id1); }

  private native void SetRange_22(double id0[]);
  public void SetRange(double id0[])
    { SetRange_22(id0); }

  private native void SetUnscaledRange_23(double id0,double id1);
  public void SetUnscaledRange(double id0,double id1)
    { SetUnscaledRange_23(id0,id1); }

  private native void SetUnscaledRange_24(double id0[]);
  public void SetUnscaledRange(double id0[])
    { SetUnscaledRange_24(id0); }

  private native void SetMinimumLimit_25(double id0);
  public void SetMinimumLimit(double id0)
    { SetMinimumLimit_25(id0); }

  private native double GetMinimumLimit_26();
  public double GetMinimumLimit()
    { return GetMinimumLimit_26(); }

  private native void SetMaximumLimit_27(double id0);
  public void SetMaximumLimit(double id0)
    { SetMaximumLimit_27(id0); }

  private native double GetMaximumLimit_28();
  public double GetMaximumLimit()
    { return GetMaximumLimit_28(); }

  private native void SetUnscaledMinimumLimit_29(double id0);
  public void SetUnscaledMinimumLimit(double id0)
    { SetUnscaledMinimumLimit_29(id0); }

  private native double GetUnscaledMinimumLimit_30();
  public double GetUnscaledMinimumLimit()
    { return GetUnscaledMinimumLimit_30(); }

  private native void SetUnscaledMaximumLimit_31(double id0);
  public void SetUnscaledMaximumLimit(double id0)
    { SetUnscaledMaximumLimit_31(id0); }

  private native double GetUnscaledMaximumLimit_32();
  public double GetUnscaledMaximumLimit()
    { return GetUnscaledMaximumLimit_32(); }

  private native int[]  GetMargins_33();
  public int[]  GetMargins()
    { return GetMargins_33(); }

  private native void SetMargins_34(int id0,int id1);
  public void SetMargins(int id0,int id1)
    { SetMargins_34(id0,id1); }

  private native void SetMargins_35(int id0[]);
  public void SetMargins(int id0[])
    { SetMargins_35(id0); }

  private native void SetTitle_36(String id0);
  public void SetTitle(String id0)
    { SetTitle_36(id0); }

  private native String GetTitle_37();
  public String GetTitle()
    { return GetTitle_37(); }

  private native long GetTitleProperties_38();
  public vtkTextProperty GetTitleProperties() {
    long temp = GetTitleProperties_38();

    if (temp == 0) return null;
    return (vtkTextProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native boolean GetLogScaleActive_39();
  public boolean GetLogScaleActive()
    { return GetLogScaleActive_39(); }

  private native boolean GetLogScale_40();
  public boolean GetLogScale()
    { return GetLogScale_40(); }

  private native void SetLogScale_41(boolean id0);
  public void SetLogScale(boolean id0)
    { SetLogScale_41(id0); }

  private native void LogScaleOn_42();
  public void LogScaleOn()
    { LogScaleOn_42(); }

  private native void LogScaleOff_43();
  public void LogScaleOff()
    { LogScaleOff_43(); }

  private native void SetGridVisible_44(boolean id0);
  public void SetGridVisible(boolean id0)
    { SetGridVisible_44(id0); }

  private native boolean GetGridVisible_45();
  public boolean GetGridVisible()
    { return GetGridVisible_45(); }

  private native void SetLabelsVisible_46(boolean id0);
  public void SetLabelsVisible(boolean id0)
    { SetLabelsVisible_46(id0); }

  private native boolean GetLabelsVisible_47();
  public boolean GetLabelsVisible()
    { return GetLabelsVisible_47(); }

  private native void SetRangeLabelsVisible_48(boolean id0);
  public void SetRangeLabelsVisible(boolean id0)
    { SetRangeLabelsVisible_48(id0); }

  private native boolean GetRangeLabelsVisible_49();
  public boolean GetRangeLabelsVisible()
    { return GetRangeLabelsVisible_49(); }

  private native void SetLabelOffset_50(double id0);
  public void SetLabelOffset(double id0)
    { SetLabelOffset_50(id0); }

  private native double GetLabelOffset_51();
  public double GetLabelOffset()
    { return GetLabelOffset_51(); }

  private native void SetTicksVisible_52(boolean id0);
  public void SetTicksVisible(boolean id0)
    { SetTicksVisible_52(id0); }

  private native boolean GetTicksVisible_53();
  public boolean GetTicksVisible()
    { return GetTicksVisible_53(); }

  private native void SetAxisVisible_54(boolean id0);
  public void SetAxisVisible(boolean id0)
    { SetAxisVisible_54(id0); }

  private native boolean GetAxisVisible_55();
  public boolean GetAxisVisible()
    { return GetAxisVisible_55(); }

  private native void SetTitleVisible_56(boolean id0);
  public void SetTitleVisible(boolean id0)
    { SetTitleVisible_56(id0); }

  private native boolean GetTitleVisible_57();
  public boolean GetTitleVisible()
    { return GetTitleVisible_57(); }

  private native void SetPrecision_58(int id0);
  public void SetPrecision(int id0)
    { SetPrecision_58(id0); }

  private native int GetPrecision_59();
  public int GetPrecision()
    { return GetPrecision_59(); }

  private native void SetLabelFormat_60(String id0);
  public void SetLabelFormat(String id0)
    { SetLabelFormat_60(id0); }

  private native String GetLabelFormat_61();
  public String GetLabelFormat()
    { return GetLabelFormat_61(); }

  private native void SetRangeLabelFormat_62(String id0);
  public void SetRangeLabelFormat(String id0)
    { SetRangeLabelFormat_62(id0); }

  private native String GetRangeLabelFormat_63();
  public String GetRangeLabelFormat()
    { return GetRangeLabelFormat_63(); }

  private native void SetNotation_64(int id0);
  public void SetNotation(int id0)
    { SetNotation_64(id0); }

  private native int GetNotation_65();
  public int GetNotation()
    { return GetNotation_65(); }

  private native void SetBehavior_66(int id0);
  public void SetBehavior(int id0)
    { SetBehavior_66(id0); }

  private native int GetBehavior_67();
  public int GetBehavior()
    { return GetBehavior_67(); }

  private native long GetPen_68();
  public vtkPen GetPen() {
    long temp = GetPen_68();

    if (temp == 0) return null;
    return (vtkPen)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetGridPen_69();
  public vtkPen GetGridPen() {
    long temp = GetGridPen_69();

    if (temp == 0) return null;
    return (vtkPen)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetTickLabelAlgorithm_70(int id0);
  public void SetTickLabelAlgorithm(int id0)
    { SetTickLabelAlgorithm_70(id0); }

  private native int GetTickLabelAlgorithm_71();
  public int GetTickLabelAlgorithm()
    { return GetTickLabelAlgorithm_71(); }

  private native void SetScalingFactor_72(double id0);
  public void SetScalingFactor(double id0)
    { SetScalingFactor_72(id0); }

  private native double GetScalingFactor_73();
  public double GetScalingFactor()
    { return GetScalingFactor_73(); }

  private native void SetShift_74(double id0);
  public void SetShift(double id0)
    { SetShift_74(id0); }

  private native double GetShift_75();
  public double GetShift()
    { return GetShift_75(); }

  private native void Update_76();
  public void Update()
    { Update_76(); }

  private native boolean Paint_77(vtkContext2D id0);
  public boolean Paint(vtkContext2D id0)
    { return Paint_77(id0); }

  private native void AutoScale_78();
  public void AutoScale()
    { AutoScale_78(); }

  private native void RecalculateTickSpacing_79();
  public void RecalculateTickSpacing()
    { RecalculateTickSpacing_79(); }

  private native long GetTickPositions_80();
  public vtkDoubleArray GetTickPositions() {
    long temp = GetTickPositions_80();

    if (temp == 0) return null;
    return (vtkDoubleArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetTickScenePositions_81();
  public vtkFloatArray GetTickScenePositions() {
    long temp = GetTickScenePositions_81();

    if (temp == 0) return null;
    return (vtkFloatArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetTickLabels_82();
  public vtkStringArray GetTickLabels() {
    long temp = GetTickLabels_82();

    if (temp == 0) return null;
    return (vtkStringArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native boolean SetCustomTickPositions_83(vtkDoubleArray id0,vtkStringArray id1);
  public boolean SetCustomTickPositions(vtkDoubleArray id0,vtkStringArray id1)
    { return SetCustomTickPositions_83(id0,id1); }

  private native double NiceNumber_84(double id0,boolean id1);
  public double NiceNumber(double id0,boolean id1)
    { return NiceNumber_84(id0,id1); }

  private native String GenerateSimpleLabel_85(double id0);
  public String GenerateSimpleLabel(double id0)
    { return GenerateSimpleLabel_85(id0); }

  public vtkAxis() { super(); }

  public vtkAxis(long id) { super(id); }
  public native long   VTKInit();

}
